--------------------------------------------------------------------
--
-- tcl-ada.adb --
--
-- Copyright (c) 1995-1996 Terry J. Westley
--
-- See the file "license_terms.html" for information on usage and
-- redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.
--
--------------------------------------------------------------------

with Ada.Exceptions;

package body Tcl.Ada is

   function "=" (Left, Right : in C.Int) return Boolean renames C."=";

   procedure Assert (
      Interp      : Tcl_Interp;
      Return_Code : C.Int) is
   -- Raises Tcl_Error_Exception if Return_Code = TCL_ERROR
   begin -- Assert
      if Return_Code = TCL_ERROR then
	 Standard.Ada.Exceptions.Raise_Exception (
            Tcl_Error_Exception'Identity, Tcl_GetResult (Interp));
      end if;
   end Assert;

   package body Generic_AssocData is

      function Tcl_GetAssocData (
         interp          : in Tcl_Interp;
         name            : in String;
         procPtr         : in Tcl_InterpDeleteProc
      ) return ClientData is
         C_name : C.Strings.Chars_Ptr := C.Strings.New_String (name);
      begin -- Tcl_GetAssocData
         return Tcl_GetAssocData (
            interp,
            C_name,
            procPtr);
      end Tcl_GetAssocData;

      procedure Tcl_SetAssocData (
         interp          : in Tcl_Interp;
         name            : in String;
         proc            : in Tcl_InterpDeleteProc;
         data            : in ClientData
      ) is
         C_name : C.Strings.Chars_Ptr := C.Strings.New_String (name);
      begin -- Tcl_SetAssocData
         Tcl_SetAssocData (
            interp,
            C_name,
            proc,
            data);
      end Tcl_SetAssocData;

   end Generic_AssocData;

   package body Generic_AsyncEvents is

   end Generic_AsyncEvents;

   package body Generic_CallWhenDeleted is

   end Generic_CallWhenDeleted;

   package body Generic_Channel is

   end Generic_Channel;

   package body Generic_ChannelDriver is

      function Tcl_CreateChannel (
         typePtr         : in Tcl_ChannelType;
         chanName        : in String;
         instancedata    : in ClientData;
         mask            : in C.Int
      ) return Tcl_Channel is
         C_chanName : C.Strings.Chars_Ptr := C.Strings.New_String (chanName);
      begin -- Tcl_CreateChannel
         return Tcl_CreateChannel (
            typePtr,
            C_chanName,
            instancedata,
            mask);
      end Tcl_CreateChannel;

   end Generic_ChannelDriver;

   package body Generic_ChannelHandler is

   end Generic_ChannelHandler;

   package body Generic_CloseHandler is

   end Generic_CloseHandler;

   package body Generic_Command is

      function Tcl_CreateCommand (
         interp          : in Tcl_Interp;
         cmdName         : in String;
         proc            : in Tcl_CmdProc;
         data            : in ClientData;
         deleteProc      : in Tcl_CmdDeleteProc
      ) return Tcl_Command is
         C_cmdName : C.Strings.Chars_Ptr := C.Strings.New_String (cmdName);
      begin -- Tcl_CreateCommand
         return Tcl_CreateCommand (
            interp,
            C_cmdName,
            proc,
            data,
            deleteProc);
      end Tcl_CreateCommand;

   end Generic_Command;

   package body Generic_EventSource is

   end Generic_EventSource;

   package body Generic_ExitHandler is

   end Generic_ExitHandler;

   package body Generic_FileHandle is

   end Generic_FileHandle;

   package body Generic_FileHandler is

   end Generic_FileHandler;

   package body Generic_GetOpenFile is

      function Tcl_GetOpenFile (
         interp          : in Tcl_Interp;
         strng           : in String;
         write           : in C.Int;
         checkUsage      : in C.Int;
         fileptr         : in ClientData
      ) return C.Int is
         C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      begin -- Tcl_GetOpenFile
         return Tcl_GetOpenFile (
            interp,
            C_strng,
            write,
            checkUsage,
            fileptr);
      end Tcl_GetOpenFile;

      procedure Tcl_GetOpenFile (
         interp          : in Tcl_Interp;
         strng           : in String;
         write           : in C.Int;
         checkUsage      : in C.Int;
         fileptr         : in ClientData
      ) is
         C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      begin -- Tcl_GetOpenFile
         Assert (interp, Tcl_GetOpenFile (
            interp,
            C_strng,
            write,
            checkUsage,
            fileptr));
      end Tcl_GetOpenFile;

   end Generic_GetOpenFile;

   package body Generic_Hash is

   end Generic_Hash;

   package body Generic_Idle is

   end Generic_Idle;

   package body Generic_ManageStorage is

   end Generic_ManageStorage;

   package body Generic_MathFunc is

      procedure Tcl_CreateMathFunc (
         interp          : in Tcl_Interp;
         name            : in String;
         numArgs         : in C.Int;
         argTypes        : in Tcl_ValueType;
         proc            : in Tcl_MathProc;
         data            : in ClientData
      ) is
         C_name : C.Strings.Chars_Ptr := C.Strings.New_String (name);
      begin -- Tcl_CreateMathFunc
         Tcl_CreateMathFunc (
            interp,
            C_name,
            numArgs,
            argTypes,
            proc,
            data);
      end Tcl_CreateMathFunc;

   end Generic_MathFunc;

   package body Generic_ModalTimeout is

   end Generic_ModalTimeout;

   package body Generic_TcpChannel is

      function Tcl_OpenTcpServer (
         interp          : in Tcl_Interp;
         port            : in C.Int;
         host            : in String;
         acceptProc      : in Tcl_TcpAcceptProc;
         callbackdata    : in ClientData
      ) return Tcl_Channel is
         C_host : C.Strings.Chars_Ptr := C.Strings.New_String (host);
      begin -- Tcl_OpenTcpServer
         return Tcl_OpenTcpServer (
            interp,
            port,
            C_host,
            acceptProc,
            callbackdata);
      end Tcl_OpenTcpServer;

   end Generic_TcpChannel;

   package body Generic_TimerHandler is

   end Generic_TimerHandler;

   package body Generic_Trace is

   end Generic_Trace;

   package body Generic_TraceVar is

      function Tcl_TraceVar (
         interp          : in Tcl_Interp;
         varName         : in String;
         flags           : in C.Int;
         proc            : in Tcl_VarTraceProc;
         data            : in ClientData
      ) return C.Int is
         C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      begin -- Tcl_TraceVar
         return Tcl_TraceVar (
            interp,
            C_varName,
            flags,
            proc,
            data);
      end Tcl_TraceVar;

      procedure Tcl_TraceVar (
         interp          : in Tcl_Interp;
         varName         : in String;
         flags           : in C.Int;
         proc            : in Tcl_VarTraceProc;
         data            : in ClientData
      ) is
         C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      begin -- Tcl_TraceVar
         Assert (interp, Tcl_TraceVar (
            interp,
            C_varName,
            flags,
            proc,
            data));
      end Tcl_TraceVar;

      function Tcl_TraceVar2 (
         interp          : in Tcl_Interp;
         part1           : in String;
         part2           : in String;
         flags           : in C.Int;
         proc            : in Tcl_VarTraceProc;
         data            : in ClientData
      ) return C.Int is
         C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
         C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
      begin -- Tcl_TraceVar2
         return Tcl_TraceVar2 (
            interp,
            C_part1,
            C_part2,
            flags,
            proc,
            data);
      end Tcl_TraceVar2;

      procedure Tcl_TraceVar2 (
         interp          : in Tcl_Interp;
         part1           : in String;
         part2           : in String;
         flags           : in C.Int;
         proc            : in Tcl_VarTraceProc;
         data            : in ClientData
      ) is
         C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
         C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
      begin -- Tcl_TraceVar2
         Assert (interp, Tcl_TraceVar2 (
            interp,
            C_part1,
            C_part2,
            flags,
            proc,
            data));
      end Tcl_TraceVar2;

      procedure Tcl_UntraceVar (
         interp          : in Tcl_Interp;
         varName         : in String;
         flags           : in C.Int;
         proc            : in Tcl_VarTraceProc;
         data            : in ClientData
      ) is
         C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      begin -- Tcl_UntraceVar
         Tcl_UntraceVar (
            interp,
            C_varName,
            flags,
            proc,
            data);
      end Tcl_UntraceVar;

      procedure Tcl_UntraceVar2 (
         interp          : in Tcl_Interp;
         part1           : in String;
         part2           : in String;
         flags           : in C.Int;
         proc            : in Tcl_VarTraceProc;
         data            : in ClientData
      ) is
         C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
         C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
      begin -- Tcl_UntraceVar2
         Tcl_UntraceVar2 (
            interp,
            C_part1,
            C_part2,
            flags,
            proc,
            data);
      end Tcl_UntraceVar2;

      function Tcl_VarTraceInfo (
         interp          : in Tcl_Interp;
         varName         : in String;
         flags           : in C.Int;
         procPtr         : in Tcl_VarTraceProc;
         prevclientdata  : in ClientData
      ) return ClientData is
         C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      begin -- Tcl_VarTraceInfo
         return Tcl_VarTraceInfo (
            interp,
            C_varName,
            flags,
            procPtr,
            prevclientdata);
      end Tcl_VarTraceInfo;

      function Tcl_VarTraceInfo2 (
         interp          : in Tcl_Interp;
         part1           : in String;
         part2           : in String;
         flags           : in C.Int;
         procPtr         : in Tcl_VarTraceProc;
         prevclientdata  : in ClientData
      ) return ClientData is
         C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
         C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
      begin -- Tcl_VarTraceInfo2
         return Tcl_VarTraceInfo2 (
            interp,
            C_part1,
            C_part2,
            flags,
            procPtr,
            prevclientdata);
      end Tcl_VarTraceInfo2;

   end Generic_TraceVar;

   function Tcl_DStringValue (
      dsPtr           : in Tcl_DString
   ) return String is
   begin -- Tcl_DStringValue
      return CHelper.Value (Tcl.Tcl_DStringValue (
         dsPtr));
   end Tcl_DStringValue;

   function Tcl_Alloc (
      size            : in C.Unsigned
   ) return String is
   begin -- Tcl_Alloc
      return CHelper.Value (Tcl.Tcl_Alloc (
         size));
   end Tcl_Alloc;

   procedure Tcl_Free (
      ptr             : in String
   ) is
      C_ptr : C.Strings.Chars_Ptr := C.Strings.New_String (ptr);
   begin -- Tcl_Free
      Tcl.Tcl_Free (
         C_ptr);
   end Tcl_Free;

   function Tcl_Realloc (
      ptr             : in String;
      size            : in C.Unsigned
   ) return String is
      C_ptr : C.Strings.Chars_Ptr := C.Strings.New_String (ptr);
   begin -- Tcl_Realloc
      return CHelper.Value (Tcl.Tcl_Realloc (
         C_ptr,
         size));
   end Tcl_Realloc;

   procedure Tcl_AddErrorInfo (
      interp          : in Tcl_Interp;
      message         : in String
   ) is
      C_message : C.Strings.Chars_Ptr := C.Strings.New_String (message);
   begin -- Tcl_AddErrorInfo
      Tcl.Tcl_AddErrorInfo (
         interp,
         C_message);
   end Tcl_AddErrorInfo;

   procedure Tcl_AppendElement (
      interp          : in Tcl_Interp;
      strng           : in String
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_AppendElement
      Tcl.Tcl_AppendElement (
         interp,
         C_strng);
   end Tcl_AppendElement;

   procedure Tcl_AppendResult (
      interp          : in Tcl_Interp;
      String1         : in String := "";
      String2         : in String := "";
      String3         : in String := "";
      String4         : in String := "";
      String5         : in String := "";
      String6         : in String := "";
      String7         : in String := "";
      String8         : in String := "";
      String9         : in String := ""
   ) is
      C_String1 : C.Strings.Chars_Ptr := C.Strings.New_String (String1);
      C_String2 : C.Strings.Chars_Ptr := C.Strings.New_String (String2);
      C_String3 : C.Strings.Chars_Ptr := C.Strings.New_String (String3);
      C_String4 : C.Strings.Chars_Ptr := C.Strings.New_String (String4);
      C_String5 : C.Strings.Chars_Ptr := C.Strings.New_String (String5);
      C_String6 : C.Strings.Chars_Ptr := C.Strings.New_String (String6);
      C_String7 : C.Strings.Chars_Ptr := C.Strings.New_String (String7);
      C_String8 : C.Strings.Chars_Ptr := C.Strings.New_String (String8);
      C_String9 : C.Strings.Chars_Ptr := C.Strings.New_String (String9);
   begin -- Tcl_AppendResult
      Tcl.Tcl_AppendResult (
         interp,
         C_String1,
         C_String2,
         C_String3,
         C_String4,
         C_String5,
         C_String6,
         C_String7,
         C_String8,
         C_String9);
   end Tcl_AppendResult;

   procedure Tcl_Backslash (
      src             : in String;
      readPtr         : access C.Int;
      result          : out C.Char
   ) is
      C_src : C.Strings.Chars_Ptr := C.Strings.New_String (src);
   begin -- Tcl_Backslash
      result := Tcl.Tcl_Backslash (
         C_src,
         readPtr);
   end Tcl_Backslash;

   function Tcl_CommandComplete (
      cmd             : in String
   ) return C.Int is
      C_cmd : C.Strings.Chars_Ptr := C.Strings.New_String (cmd);
   begin -- Tcl_CommandComplete
      return Tcl.Tcl_CommandComplete (
         C_cmd);
   end Tcl_CommandComplete;

   function Tcl_Concat (
      argc            : in C.Int;
      argv            : in CArgv.Chars_Ptr_Ptr
   ) return String is
   begin -- Tcl_Concat
      return CHelper.Value (Tcl.Tcl_Concat (
         argc,
         argv));
   end Tcl_Concat;

   function Tcl_ConvertElement (
      src             : in String;
      dst             : in String;
      flags           : in C.Int
   ) return C.Int is
      C_src : C.Strings.Chars_Ptr := C.Strings.New_String (src);
      C_dst : C.Strings.Chars_Ptr := C.Strings.New_String (dst);
   begin -- Tcl_ConvertElement
      return Tcl.Tcl_ConvertElement (
         C_src,
         C_dst,
         flags);
   end Tcl_ConvertElement;

   function Tcl_CreateAlias (
      slave           : in Tcl_Interp;
      slaveCmd        : in String;
      target          : in Tcl_Interp;
      targetCmd       : in String;
      argc            : in C.Int;
      argv            : in CArgv.Chars_Ptr_Ptr
   ) return C.Int is
      C_slaveCmd : C.Strings.Chars_Ptr := C.Strings.New_String (slaveCmd);
      C_targetCmd : C.Strings.Chars_Ptr := C.Strings.New_String (targetCmd);
   begin -- Tcl_CreateAlias
      return Tcl.Tcl_CreateAlias (
         slave,
         C_slaveCmd,
         target,
         C_targetCmd,
         argc,
         argv);
   end Tcl_CreateAlias;

   function Tcl_CreateSlave (
      interp          : in Tcl_Interp;
      slaveName       : in String;
      isSafe          : in C.Int
   ) return Tcl_Interp is
      C_slaveName : C.Strings.Chars_Ptr := C.Strings.New_String (slaveName);
   begin -- Tcl_CreateSlave
      return Tcl.Tcl_CreateSlave (
         interp,
         C_slaveName,
         isSafe);
   end Tcl_CreateSlave;

   function Tcl_DbCkalloc (
      size            : in C.Unsigned;
      file            : in String;
      line            : in C.Int
   ) return String is
      C_file : C.Strings.Chars_Ptr := C.Strings.New_String (file);
   begin -- Tcl_DbCkalloc
      return CHelper.Value (Tcl.Tcl_DbCkalloc (
         size,
         C_file,
         line));
   end Tcl_DbCkalloc;

   function Tcl_DbCkfree (
      ptr             : in String;
      file            : in String;
      line            : in C.Int
   ) return C.Int is
      C_ptr : C.Strings.Chars_Ptr := C.Strings.New_String (ptr);
      C_file : C.Strings.Chars_Ptr := C.Strings.New_String (file);
   begin -- Tcl_DbCkfree
      return Tcl.Tcl_DbCkfree (
         C_ptr,
         C_file,
         line);
   end Tcl_DbCkfree;

   function Tcl_DbCkrealloc (
      ptr             : in String;
      size            : in C.Unsigned;
      file            : in String;
      line            : in C.Int
   ) return String is
      C_ptr : C.Strings.Chars_Ptr := C.Strings.New_String (ptr);
      C_file : C.Strings.Chars_Ptr := C.Strings.New_String (file);
   begin -- Tcl_DbCkrealloc
      return CHelper.Value (Tcl.Tcl_DbCkrealloc (
         C_ptr,
         size,
         C_file,
         line));
   end Tcl_DbCkrealloc;

   function Tcl_DStringAppend (
      dsPtr           : in Tcl_DString;
      strng           : in String;
      length          : in C.Int
   ) return String is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_DStringAppend
      return CHelper.Value (Tcl.Tcl_DStringAppend (
         dsPtr,
         C_strng,
         length));
   end Tcl_DStringAppend;

   procedure Tcl_DStringAppend (
      dsPtr           : in Tcl_DString;
      strng           : in String;
      length          : in C.Int
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      result : C.Strings.Chars_Ptr;
   begin -- Tcl_DStringAppend
      result := Tcl.Tcl_DStringAppend (
         dsPtr,
         C_strng,
         length);
   end Tcl_DStringAppend;

   function Tcl_DStringAppendElement (
      dsPtr           : in Tcl_DString;
      strng           : in String
   ) return String is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_DStringAppendElement
      return CHelper.Value (Tcl.Tcl_DStringAppendElement (
         dsPtr,
         C_strng));
   end Tcl_DStringAppendElement;

   procedure Tcl_DStringAppendElement (
      dsPtr           : in Tcl_DString;
      strng           : in String
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      result : C.Strings.Chars_Ptr;
   begin -- Tcl_DStringAppendElement
      result := Tcl.Tcl_DStringAppendElement (
         dsPtr,
         C_strng);
   end Tcl_DStringAppendElement;

   function Tcl_ErrnoId return String is
   begin -- Tcl_ErrnoId
      return CHelper.Value (Tcl.Tcl_ErrnoId);
   end Tcl_ErrnoId;

   function Tcl_ErrnoMsg (
      err             : in C.Int
   ) return String is
   begin -- Tcl_ErrnoMsg
      return CHelper.Value (Tcl.Tcl_ErrnoMsg (
         err));
   end Tcl_ErrnoMsg;

   function Tcl_Eval (
      interp          : in Tcl_Interp;
      cmd             : in String
   ) return C.Int is
      C_cmd : C.Strings.Chars_Ptr := C.Strings.New_String (cmd);
   begin -- Tcl_Eval
      return Tcl.Tcl_Eval (
         interp,
         C_cmd);
   end Tcl_Eval;

   procedure Tcl_Eval (
      interp          : in Tcl_Interp;
      cmd             : in String
   ) is
      C_cmd : C.Strings.Chars_Ptr := C.Strings.New_String (cmd);
   begin -- Tcl_Eval
      Assert (interp, Tcl.Tcl_Eval (
         interp,
         C_cmd));
   end Tcl_Eval;

   function Tcl_EvalFile (
      interp          : in Tcl_Interp;
      fileName        : in String
   ) return C.Int is
      C_fileName : C.Strings.Chars_Ptr := C.Strings.New_String (fileName);
   begin -- Tcl_EvalFile
      return Tcl.Tcl_EvalFile (
         interp,
         C_fileName);
   end Tcl_EvalFile;

   procedure Tcl_EvalFile (
      interp          : in Tcl_Interp;
      fileName        : in String
   ) is
      C_fileName : C.Strings.Chars_Ptr := C.Strings.New_String (fileName);
   begin -- Tcl_EvalFile
      Assert (interp, Tcl.Tcl_EvalFile (
         interp,
         C_fileName));
   end Tcl_EvalFile;

   function Tcl_ExprBoolean (
      interp          : in Tcl_Interp;
      strng           : in String
   ) return Boolean is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      result : C.Int;
      ptr : aliased C.Int;
   begin -- Tcl_ExprBoolean
      result := Tcl.Tcl_ExprBoolean (
         interp,
         C_strng,
         ptr'access);
      return Boolean'val (ptr);
   end Tcl_ExprBoolean;

   function Tcl_ExprDouble (
      interp          : in Tcl_Interp;
      strng           : in String
   ) return C.Double is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      result : C.Int;
      ptr : aliased C.Double;
   begin -- Tcl_ExprDouble
      result := Tcl.Tcl_ExprDouble (
         interp,
         C_strng,
         ptr'access);
      return ptr;
   end Tcl_ExprDouble;

   function Tcl_ExprLong (
      interp          : in Tcl_Interp;
      strng           : in String
   ) return C.Long is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      result : C.Int;
      ptr : aliased C.Long;
   begin -- Tcl_ExprLong
      result := Tcl.Tcl_ExprLong (
         interp,
         C_strng,
         ptr'access);
      return ptr;
   end Tcl_ExprLong;

   function Tcl_ExprString (
      interp          : in Tcl_Interp;
      strng           : in String
   ) return String is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      result : C.Int;
   begin -- Tcl_ExprString
      result := Tcl.Tcl_ExprString (
         interp,
         C_strng);
      return CHelper.Value (Tcl_GetResult (interp));
   end Tcl_ExprString;

   procedure Tcl_FindExecutable (
      argv0           : in String
   ) is
      C_argv0 : C.Strings.Chars_Ptr := C.Strings.New_String (argv0);
   begin -- Tcl_FindExecutable
      Tcl.Tcl_FindExecutable (
         C_argv0);
   end Tcl_FindExecutable;

   procedure Tcl_GetAlias (
      interp          : in Tcl_Interp;
      slaveCmd        : in String;
      targetInterpPtr : in Tcl_Interp;
      targetCmdPtr    : in CArgv.Chars_Ptr_Ptr;
      argcPtr         : access C.Int;
      argvPtr         : access CArgv.Chars_Ptr_Ptr;
      result          : out C.Int
   ) is
      C_slaveCmd : C.Strings.Chars_Ptr := C.Strings.New_String (slaveCmd);
   begin -- Tcl_GetAlias
      result := Tcl.Tcl_GetAlias (
         interp,
         C_slaveCmd,
         targetInterpPtr,
         targetCmdPtr,
         argcPtr,
         argvPtr);
   end Tcl_GetAlias;

   procedure Tcl_GetBoolean (
      interp          : in Tcl_Interp;
      strng           : in String;
      boolPtr         : access C.Int;
      result          : out C.Int
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_GetBoolean
      result := Tcl.Tcl_GetBoolean (
         interp,
         C_strng,
         boolPtr);
   end Tcl_GetBoolean;

   procedure Tcl_GetDouble (
      interp          : in Tcl_Interp;
      strng           : in String;
      doublePtr       : access C.Double;
      result          : out C.Int
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_GetDouble
      result := Tcl.Tcl_GetDouble (
         interp,
         C_strng,
         doublePtr);
   end Tcl_GetDouble;

   function Tcl_GetHostName return String is
   begin -- Tcl_GetHostName
      return CHelper.Value (Tcl.Tcl_GetHostName);
   end Tcl_GetHostName;

   procedure Tcl_GetInt (
      interp          : in Tcl_Interp;
      strng           : in String;
      intPtr          : access C.Int;
      result          : out C.Int
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_GetInt
      result := Tcl.Tcl_GetInt (
         interp,
         C_strng,
         intPtr);
   end Tcl_GetInt;

   function Tcl_GetPathType (
      path            : in String
   ) return Tcl_PathType is
      C_path : C.Strings.Chars_Ptr := C.Strings.New_String (path);
   begin -- Tcl_GetPathType
      return Tcl.Tcl_GetPathType (
         C_path);
   end Tcl_GetPathType;

   function Tcl_GetSlave (
      interp          : in Tcl_Interp;
      slaveName       : in String
   ) return Tcl_Interp is
      C_slaveName : C.Strings.Chars_Ptr := C.Strings.New_String (slaveName);
   begin -- Tcl_GetSlave
      return Tcl.Tcl_GetSlave (
         interp,
         C_slaveName);
   end Tcl_GetSlave;

   function Tcl_GetVar (
      interp          : in Tcl_Interp;
      varName         : in String;
      flags           : in C.Int
   ) return String is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
   begin -- Tcl_GetVar
      return CHelper.Value (Tcl.Tcl_GetVar (
         interp,
         C_varName,
         flags));
   end Tcl_GetVar;

   function Tcl_GetVar2 (
      interp          : in Tcl_Interp;
      part1           : in String;
      part2           : in String;
      flags           : in C.Int
   ) return String is
      C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
      C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
   begin -- Tcl_GetVar2
      return CHelper.Value (Tcl.Tcl_GetVar2 (
         interp,
         C_part1,
         C_part2,
         flags));
   end Tcl_GetVar2;

   function Tcl_GlobalEval (
      interp          : in Tcl_Interp;
      command         : in String
   ) return C.Int is
      C_command : C.Strings.Chars_Ptr := C.Strings.New_String (command);
   begin -- Tcl_GlobalEval
      return Tcl.Tcl_GlobalEval (
         interp,
         C_command);
   end Tcl_GlobalEval;

   procedure Tcl_GlobalEval (
      interp          : in Tcl_Interp;
      command         : in String
   ) is
      C_command : C.Strings.Chars_Ptr := C.Strings.New_String (command);
   begin -- Tcl_GlobalEval
      Assert (interp, Tcl.Tcl_GlobalEval (
         interp,
         C_command));
   end Tcl_GlobalEval;

   function Tcl_JoinPath (
      argc            : in C.Int;
      argv            : in CArgv.Chars_Ptr_Ptr;
      resultPtr       : in Tcl_DString
   ) return String is
   begin -- Tcl_JoinPath
      return CHelper.Value (Tcl.Tcl_JoinPath (
         argc,
         argv,
         resultPtr));
   end Tcl_JoinPath;

   function Tcl_LinkVar (
      interp          : in Tcl_Interp;
      varName         : in String;
      addr            : in String;
      typ             : in C.Int
   ) return C.Int is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      C_addr : C.Strings.Chars_Ptr := C.Strings.New_String (addr);
   begin -- Tcl_LinkVar
      return Tcl.Tcl_LinkVar (
         interp,
         C_varName,
         C_addr,
         typ);
   end Tcl_LinkVar;

   procedure Tcl_LinkVar (
      interp          : in Tcl_Interp;
      varName         : in String;
      addr            : in String;
      typ             : in C.Int
   ) is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      C_addr : C.Strings.Chars_Ptr := C.Strings.New_String (addr);
   begin -- Tcl_LinkVar
      Assert (interp, Tcl.Tcl_LinkVar (
         interp,
         C_varName,
         C_addr,
         typ));
   end Tcl_LinkVar;

   function Tcl_Merge (
      argc            : in C.Int;
      argv            : in CArgv.Chars_Ptr_Ptr
   ) return String is
   begin -- Tcl_Merge
      return CHelper.Value (Tcl.Tcl_Merge (
         argc,
         argv));
   end Tcl_Merge;

   function Tcl_ParseVar (
      interp          : in Tcl_Interp;
      strng           : in String;
      termPtr         : in CArgv.Chars_Ptr_Ptr
   ) return String is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_ParseVar
      return CHelper.Value (Tcl.Tcl_ParseVar (
         interp,
         C_strng,
         termPtr));
   end Tcl_ParseVar;

   function Tcl_PkgProvide (
      interp          : in Tcl_Interp;
      name            : in String;
      version         : in String
   ) return C.Int is
      C_name : C.Strings.Chars_Ptr := C.Strings.New_String (name);
      C_version : C.Strings.Chars_Ptr := C.Strings.New_String (version);
   begin -- Tcl_PkgProvide
      return Tcl.Tcl_PkgProvide (
         interp,
         C_name,
         C_version);
   end Tcl_PkgProvide;

   procedure Tcl_PkgProvide (
      interp          : in Tcl_Interp;
      name            : in String;
      version         : in String
   ) is
      C_name : C.Strings.Chars_Ptr := C.Strings.New_String (name);
      C_version : C.Strings.Chars_Ptr := C.Strings.New_String (version);
   begin -- Tcl_PkgProvide
      Assert (interp, Tcl.Tcl_PkgProvide (
         interp,
         C_name,
         C_version));
   end Tcl_PkgProvide;

   function Tcl_PkgRequire (
      interp          : in Tcl_Interp;
      name            : in String;
      version         : in String;
      exact           : in C.Int
   ) return String is
      C_name : C.Strings.Chars_Ptr := C.Strings.New_String (name);
      C_version : C.Strings.Chars_Ptr := C.Strings.New_String (version);
   begin -- Tcl_PkgRequire
      return CHelper.Value (Tcl.Tcl_PkgRequire (
         interp,
         C_name,
         C_version,
         exact));
   end Tcl_PkgRequire;

   function Tcl_PosixError (
      interp          : in Tcl_Interp
   ) return String is
   begin -- Tcl_PosixError
      return CHelper.Value (Tcl.Tcl_PosixError (
         interp));
   end Tcl_PosixError;

   procedure Tcl_PrintDouble (
      interp          : in Tcl_Interp;
      value           : in C.Double;
      dst             : in String
   ) is
      C_dst : C.Strings.Chars_Ptr := C.Strings.New_String (dst);
   begin -- Tcl_PrintDouble
      Tcl.Tcl_PrintDouble (
         interp,
         value,
         C_dst);
   end Tcl_PrintDouble;

   function Tcl_PutEnv (
      strng           : in String
   ) return C.Int is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_PutEnv
      return Tcl.Tcl_PutEnv (
         C_strng);
   end Tcl_PutEnv;

   function Tcl_RecordAndEval (
      interp          : in Tcl_Interp;
      cmd             : in String;
      flags           : in C.Int
   ) return C.Int is
      C_cmd : C.Strings.Chars_Ptr := C.Strings.New_String (cmd);
   begin -- Tcl_RecordAndEval
      return Tcl.Tcl_RecordAndEval (
         interp,
         C_cmd,
         flags);
   end Tcl_RecordAndEval;

   procedure Tcl_RecordAndEval (
      interp          : in Tcl_Interp;
      cmd             : in String;
      flags           : in C.Int
   ) is
      C_cmd : C.Strings.Chars_Ptr := C.Strings.New_String (cmd);
   begin -- Tcl_RecordAndEval
      Assert (interp, Tcl.Tcl_RecordAndEval (
         interp,
         C_cmd,
         flags));
   end Tcl_RecordAndEval;

   function Tcl_RegExpCompile (
      interp          : in Tcl_Interp;
      strng           : in String
   ) return Tcl_RegExp is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_RegExpCompile
      return Tcl.Tcl_RegExpCompile (
         interp,
         C_strng);
   end Tcl_RegExpCompile;

   function Tcl_RegExpExec (
      interp          : in Tcl_Interp;
      regexp          : in Tcl_RegExp;
      strng           : in String;
      start           : in String
   ) return C.Int is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      C_start : C.Strings.Chars_Ptr := C.Strings.New_String (start);
   begin -- Tcl_RegExpExec
      return Tcl.Tcl_RegExpExec (
         interp,
         regexp,
         C_strng,
         C_start);
   end Tcl_RegExpExec;

   procedure Tcl_RegExpExec (
      interp          : in Tcl_Interp;
      regexp          : in Tcl_RegExp;
      strng           : in String;
      start           : in String
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      C_start : C.Strings.Chars_Ptr := C.Strings.New_String (start);
   begin -- Tcl_RegExpExec
      Assert (interp, Tcl.Tcl_RegExpExec (
         interp,
         regexp,
         C_strng,
         C_start));
   end Tcl_RegExpExec;

   function Tcl_RegExpMatch (
      interp          : in Tcl_Interp;
      strng           : in String;
      pattern         : in String
   ) return C.Int is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      C_pattern : C.Strings.Chars_Ptr := C.Strings.New_String (pattern);
   begin -- Tcl_RegExpMatch
      return Tcl.Tcl_RegExpMatch (
         interp,
         C_strng,
         C_pattern);
   end Tcl_RegExpMatch;

   procedure Tcl_RegExpMatch (
      interp          : in Tcl_Interp;
      strng           : in String;
      pattern         : in String
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      C_pattern : C.Strings.Chars_Ptr := C.Strings.New_String (pattern);
   begin -- Tcl_RegExpMatch
      Assert (interp, Tcl.Tcl_RegExpMatch (
         interp,
         C_strng,
         C_pattern));
   end Tcl_RegExpMatch;

   procedure Tcl_ScanElement (
      strng           : in String;
      flagPtr         : access C.Int;
      result          : out C.Int
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_ScanElement
      result := Tcl.Tcl_ScanElement (
         C_strng,
         flagPtr);
   end Tcl_ScanElement;

   procedure Tcl_SetErrorCode (
      interp          : in Tcl_Interp;
      String1         : in String := "";
      String2         : in String := "";
      String3         : in String := "";
      String4         : in String := "";
      String5         : in String := "";
      String6         : in String := "";
      String7         : in String := "";
      String8         : in String := "";
      String9         : in String := ""
   ) is
      C_String1 : C.Strings.Chars_Ptr := C.Strings.New_String (String1);
      C_String2 : C.Strings.Chars_Ptr := C.Strings.New_String (String2);
      C_String3 : C.Strings.Chars_Ptr := C.Strings.New_String (String3);
      C_String4 : C.Strings.Chars_Ptr := C.Strings.New_String (String4);
      C_String5 : C.Strings.Chars_Ptr := C.Strings.New_String (String5);
      C_String6 : C.Strings.Chars_Ptr := C.Strings.New_String (String6);
      C_String7 : C.Strings.Chars_Ptr := C.Strings.New_String (String7);
      C_String8 : C.Strings.Chars_Ptr := C.Strings.New_String (String8);
      C_String9 : C.Strings.Chars_Ptr := C.Strings.New_String (String9);
   begin -- Tcl_SetErrorCode
      Tcl.Tcl_SetErrorCode (
         interp,
         C_String1,
         C_String2,
         C_String3,
         C_String4,
         C_String5,
         C_String6,
         C_String7,
         C_String8,
         C_String9);
   end Tcl_SetErrorCode;

   procedure Tcl_SetResult (
      interp          : in Tcl_Interp;
      strng           : in String
   ) is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
   begin -- Tcl_SetResult
      Tcl.Tcl_SetResult (
         interp,
         C_strng,
         C.Int (TCL_VOLATILE));
   end Tcl_SetResult;

   function Tcl_SetVar (
      interp          : in Tcl_Interp;
      varName         : in String;
      newValue        : in String;
      flags           : in C.Int
   ) return String is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      C_newValue : C.Strings.Chars_Ptr := C.Strings.New_String (newValue);
   begin -- Tcl_SetVar
      return CHelper.Value (Tcl.Tcl_SetVar (
         interp,
         C_varName,
         C_newValue,
         flags));
   end Tcl_SetVar;

   procedure Tcl_SetVar (
      interp          : in Tcl_Interp;
      varName         : in String;
      newValue        : in String;
      flags           : in C.Int
   ) is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      C_newValue : C.Strings.Chars_Ptr := C.Strings.New_String (newValue);
      result : C.Strings.Chars_Ptr;
   begin -- Tcl_SetVar
      result := Tcl.Tcl_SetVar (
         interp,
         C_varName,
         C_newValue,
         flags);
   end Tcl_SetVar;

   function Tcl_SetVar2 (
      interp          : in Tcl_Interp;
      part1           : in String;
      part2           : in String;
      newValue        : in String;
      flags           : in C.Int
   ) return String is
      C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
      C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
      C_newValue : C.Strings.Chars_Ptr := C.Strings.New_String (newValue);
   begin -- Tcl_SetVar2
      return CHelper.Value (Tcl.Tcl_SetVar2 (
         interp,
         C_part1,
         C_part2,
         C_newValue,
         flags));
   end Tcl_SetVar2;

   procedure Tcl_SetVar2 (
      interp          : in Tcl_Interp;
      part1           : in String;
      part2           : in String;
      newValue        : in String;
      flags           : in C.Int
   ) is
      C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
      C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
      C_newValue : C.Strings.Chars_Ptr := C.Strings.New_String (newValue);
      result : C.Strings.Chars_Ptr;
   begin -- Tcl_SetVar2
      result := Tcl.Tcl_SetVar2 (
         interp,
         C_part1,
         C_part2,
         C_newValue,
         flags);
   end Tcl_SetVar2;

   function Tcl_SignalId (
      sig             : in C.Int
   ) return String is
   begin -- Tcl_SignalId
      return CHelper.Value (Tcl.Tcl_SignalId (
         sig));
   end Tcl_SignalId;

   function Tcl_SignalMsg (
      sig             : in C.Int
   ) return String is
   begin -- Tcl_SignalMsg
      return CHelper.Value (Tcl.Tcl_SignalMsg (
         sig));
   end Tcl_SignalMsg;

   procedure Tcl_SplitList (
      interp          : in Tcl_Interp;
      list            : in String;
      argcPtr         : access C.Int;
      argvPtr         : access CArgv.Chars_Ptr_Ptr;
      result          : out C.Int
   ) is
      C_list : C.Strings.Chars_Ptr := C.Strings.New_String (list);
   begin -- Tcl_SplitList
      result := Tcl.Tcl_SplitList (
         interp,
         C_list,
         argcPtr,
         argvPtr);
   end Tcl_SplitList;

   procedure Tcl_SplitPath (
      path            : in String;
      argcPtr         : access C.Int;
      argvPtr         : access CArgv.Chars_Ptr_Ptr
   ) is
      C_path : C.Strings.Chars_Ptr := C.Strings.New_String (path);
   begin -- Tcl_SplitPath
      Tcl.Tcl_SplitPath (
         C_path,
         argcPtr,
         argvPtr);
   end Tcl_SplitPath;

   procedure Tcl_StaticPackage (
      interp          : in Tcl_Interp;
      pkgName         : in String;
      initProc        : in Tcl_PackageInitProc;
      safeInitProc    : in Tcl_PackageInitProc
   ) is
      C_pkgName : C.Strings.Chars_Ptr := C.Strings.New_String (pkgName);
   begin -- Tcl_StaticPackage
      Tcl.Tcl_StaticPackage (
         interp,
         C_pkgName,
         initProc,
         safeInitProc);
   end Tcl_StaticPackage;

   function Tcl_StringMatch (
      strng           : in String;
      pattern         : in String
   ) return C.Int is
      C_strng : C.Strings.Chars_Ptr := C.Strings.New_String (strng);
      C_pattern : C.Strings.Chars_Ptr := C.Strings.New_String (pattern);
   begin -- Tcl_StringMatch
      return Tcl.Tcl_StringMatch (
         C_strng,
         C_pattern);
   end Tcl_StringMatch;

   procedure Tcl_UnlinkVar (
      interp          : in Tcl_Interp;
      varName         : in String
   ) is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
   begin -- Tcl_UnlinkVar
      Tcl.Tcl_UnlinkVar (
         interp,
         C_varName);
   end Tcl_UnlinkVar;

   function Tcl_UnsetVar (
      interp          : in Tcl_Interp;
      varName         : in String;
      flags           : in C.Int
   ) return C.Int is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
   begin -- Tcl_UnsetVar
      return Tcl.Tcl_UnsetVar (
         interp,
         C_varName,
         flags);
   end Tcl_UnsetVar;

   procedure Tcl_UnsetVar (
      interp          : in Tcl_Interp;
      varName         : in String;
      flags           : in C.Int
   ) is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
   begin -- Tcl_UnsetVar
      Assert (interp, Tcl.Tcl_UnsetVar (
         interp,
         C_varName,
         flags));
   end Tcl_UnsetVar;

   function Tcl_UnsetVar2 (
      interp          : in Tcl_Interp;
      part1           : in String;
      part2           : in String;
      flags           : in C.Int
   ) return C.Int is
      C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
      C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
   begin -- Tcl_UnsetVar2
      return Tcl.Tcl_UnsetVar2 (
         interp,
         C_part1,
         C_part2,
         flags);
   end Tcl_UnsetVar2;

   procedure Tcl_UnsetVar2 (
      interp          : in Tcl_Interp;
      part1           : in String;
      part2           : in String;
      flags           : in C.Int
   ) is
      C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
      C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
   begin -- Tcl_UnsetVar2
      Assert (interp, Tcl.Tcl_UnsetVar2 (
         interp,
         C_part1,
         C_part2,
         flags));
   end Tcl_UnsetVar2;

   procedure Tcl_UpdateLinkedVar (
      interp          : in Tcl_Interp;
      varName         : in String
   ) is
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
   begin -- Tcl_UpdateLinkedVar
      Tcl.Tcl_UpdateLinkedVar (
         interp,
         C_varName);
   end Tcl_UpdateLinkedVar;

   function Tcl_UpVar (
      interp          : in Tcl_Interp;
      frameName       : in String;
      varName         : in String;
      localName       : in String;
      flags           : in C.Int
   ) return C.Int is
      C_frameName : C.Strings.Chars_Ptr := C.Strings.New_String (frameName);
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      C_localName : C.Strings.Chars_Ptr := C.Strings.New_String (localName);
   begin -- Tcl_UpVar
      return Tcl.Tcl_UpVar (
         interp,
         C_frameName,
         C_varName,
         C_localName,
         flags);
   end Tcl_UpVar;

   procedure Tcl_UpVar (
      interp          : in Tcl_Interp;
      frameName       : in String;
      varName         : in String;
      localName       : in String;
      flags           : in C.Int
   ) is
      C_frameName : C.Strings.Chars_Ptr := C.Strings.New_String (frameName);
      C_varName : C.Strings.Chars_Ptr := C.Strings.New_String (varName);
      C_localName : C.Strings.Chars_Ptr := C.Strings.New_String (localName);
   begin -- Tcl_UpVar
      Assert (interp, Tcl.Tcl_UpVar (
         interp,
         C_frameName,
         C_varName,
         C_localName,
         flags));
   end Tcl_UpVar;

   function Tcl_UpVar2 (
      interp          : in Tcl_Interp;
      frameName       : in String;
      part1           : in String;
      part2           : in String;
      localName       : in String;
      flags           : in C.Int
   ) return C.Int is
      C_frameName : C.Strings.Chars_Ptr := C.Strings.New_String (frameName);
      C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
      C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
      C_localName : C.Strings.Chars_Ptr := C.Strings.New_String (localName);
   begin -- Tcl_UpVar2
      return Tcl.Tcl_UpVar2 (
         interp,
         C_frameName,
         C_part1,
         C_part2,
         C_localName,
         flags);
   end Tcl_UpVar2;

   procedure Tcl_UpVar2 (
      interp          : in Tcl_Interp;
      frameName       : in String;
      part1           : in String;
      part2           : in String;
      localName       : in String;
      flags           : in C.Int
   ) is
      C_frameName : C.Strings.Chars_Ptr := C.Strings.New_String (frameName);
      C_part1 : C.Strings.Chars_Ptr := C.Strings.New_String (part1);
      C_part2 : C.Strings.Chars_Ptr := C.Strings.New_String (part2);
      C_localName : C.Strings.Chars_Ptr := C.Strings.New_String (localName);
   begin -- Tcl_UpVar2
      Assert (interp, Tcl.Tcl_UpVar2 (
         interp,
         C_frameName,
         C_part1,
         C_part2,
         C_localName,
         flags));
   end Tcl_UpVar2;

   function Tcl_VarEval (
      interp          : in Tcl_Interp;
      String1         : in String := "";
      String2         : in String := "";
      String3         : in String := "";
      String4         : in String := "";
      String5         : in String := "";
      String6         : in String := "";
      String7         : in String := "";
      String8         : in String := "";
      String9         : in String := ""
   ) return C.Int is
      C_String1 : C.Strings.Chars_Ptr := C.Strings.New_String (String1);
      C_String2 : C.Strings.Chars_Ptr := C.Strings.New_String (String2);
      C_String3 : C.Strings.Chars_Ptr := C.Strings.New_String (String3);
      C_String4 : C.Strings.Chars_Ptr := C.Strings.New_String (String4);
      C_String5 : C.Strings.Chars_Ptr := C.Strings.New_String (String5);
      C_String6 : C.Strings.Chars_Ptr := C.Strings.New_String (String6);
      C_String7 : C.Strings.Chars_Ptr := C.Strings.New_String (String7);
      C_String8 : C.Strings.Chars_Ptr := C.Strings.New_String (String8);
      C_String9 : C.Strings.Chars_Ptr := C.Strings.New_String (String9);
   begin -- Tcl_VarEval
      return Tcl.Tcl_VarEval (
         interp,
         C_String1,
         C_String2,
         C_String3,
         C_String4,
         C_String5,
         C_String6,
         C_String7,
         C_String8,
         C_String9);
   end Tcl_VarEval;

   procedure Tcl_VarEval (
      interp          : in Tcl_Interp;
      String1         : in String := "";
      String2         : in String := "";
      String3         : in String := "";
      String4         : in String := "";
      String5         : in String := "";
      String6         : in String := "";
      String7         : in String := "";
      String8         : in String := "";
      String9         : in String := ""
   ) is
      C_String1 : C.Strings.Chars_Ptr := C.Strings.New_String (String1);
      C_String2 : C.Strings.Chars_Ptr := C.Strings.New_String (String2);
      C_String3 : C.Strings.Chars_Ptr := C.Strings.New_String (String3);
      C_String4 : C.Strings.Chars_Ptr := C.Strings.New_String (String4);
      C_String5 : C.Strings.Chars_Ptr := C.Strings.New_String (String5);
      C_String6 : C.Strings.Chars_Ptr := C.Strings.New_String (String6);
      C_String7 : C.Strings.Chars_Ptr := C.Strings.New_String (String7);
      C_String8 : C.Strings.Chars_Ptr := C.Strings.New_String (String8);
      C_String9 : C.Strings.Chars_Ptr := C.Strings.New_String (String9);
   begin -- Tcl_VarEval
      Assert (interp, Tcl.Tcl_VarEval (
         interp,
         C_String1,
         C_String2,
         C_String3,
         C_String4,
         C_String5,
         C_String6,
         C_String7,
         C_String8,
         C_String9));
   end Tcl_VarEval;

   function Tcl_GetResult (
      interp          : in Tcl_Interp
   ) return String is
   begin -- Tcl_GetResult
      return CHelper.Value (Tcl.Tcl_GetResult (
         interp));
   end Tcl_GetResult;


end Tcl.Ada;

